/*
 * Licensed to Elasticsearch under one or more contributor
 * license agreements. See the NOTICE file distributed with
 * this work for additional information regarding copyright
 * ownership. Elasticsearch licenses this file to you under
 * the Apache License, Version 2.0 (the "License"); you may
 * not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package org.elasticsearch.client.dataframe.transforms;

import org.elasticsearch.common.xcontent.XContentBuilder;
import org.elasticsearch.test.ESTestCase;

import java.io.IOException;

import static org.elasticsearch.test.AbstractXContentTestCase.xContentTester;

public class DataFrameTransformStateAndStatsTests extends ESTestCase {

    public void testFromXContent() throws IOException {
        xContentTester(this::createParser,
                DataFrameTransformStateAndStatsTests::randomInstance,
                DataFrameTransformStateAndStatsTests::toXContent,
                DataFrameTransformStateAndStats::fromXContent)
                .supportsUnknownFields(true)
                .randomFieldsExcludeFilter(field -> field.startsWith("state"))
                .test();
    }

    public static DataFrameTransformStateAndStats randomInstance() {
        return new DataFrameTransformStateAndStats(randomAlphaOfLength(10),
                DataFrameTransformStateTests.randomDataFrameTransformState(),
                DataFrameIndexerTransformStatsTests.randomStats());
    }

    public static void toXContent(DataFrameTransformStateAndStats stateAndStats, XContentBuilder builder) throws IOException {
        builder.startObject();
        builder.field(DataFrameTransformStateAndStats.ID.getPreferredName(), stateAndStats.getId());
        builder.field(DataFrameTransformStateAndStats.STATE_FIELD.getPreferredName());
        DataFrameTransformStateTests.toXContent(stateAndStats.getTransformState(), builder);
        builder.field(DataFrameTransformStateAndStats.STATS_FIELD.getPreferredName());
        DataFrameIndexerTransformStatsTests.toXContent(stateAndStats.getTransformStats(), builder);
        builder.endObject();
    }
}
